@@ -5,9 +5,11 @@ Standard Ebooks epub3 files.
 """
 
 import base64
+from copy import deepcopy
 import datetime
 import os
 from pathlib import Path
+import importlib.resources
 from typing import Dict, List, Optional, Tuple, Union
 
 import git
@@ -16,6 +18,7 @@ from natsort import natsorted
 import regex
 
 import se
+import se.css
 import se.easy_xml
 import se.formatting
 import se.images
@@ -550,7 +553,7 @@ class SeEpub:
 		for filepath in css_filenames:
 			file_css = self.get_file(filepath)
 
-			namespaces = namespaces + regex.findall(r"@namespace.+?;", file_css)
+			namespaces += regex.findall(r"@namespace.+?;", file_css)
 
 			file_css = regex.sub(r"\s*@(charset|namespace).+?;\s*", "\n", file_css).strip()
 
@@ -696,7 +699,7 @@ class SeEpub:
 			output_xhtml = output_xhtml.replace("epub|type", "data-epub-type")
 			output_xhtml = output_xhtml.replace("xml|lang", "lang")
 			output_xhtml = regex.sub(r" xmlns.+?=\".+?\"", "", output_xhtml)
-			output_xhtml = regex.sub(r"@namespace (epub|xml).+?\s+", "", output_xhtml, flags=regex.MULTILINE)
+			output_xhtml = regex.sub(r"@namespace (epub|xml).+?\s+", "", output_xhtml)
 
 			# The Nu HTML5 Validator barfs if non-void elements are self-closed (like <td/>)
 			# Try to un-self-close them for HTML5 output.
@@ -913,6 +916,70 @@ class SeEpub:
 			with open(file_path, "w", encoding="utf-8") as file:
 				file.write(dom.to_string())
 
+	def generate_loi(self) -> str:
+		"""
+		Generate an LoI DOM based on all <figure> elements that contain an
+		<img>. Text from the <figcaption>, if any, is preferred over that from
+		the <img>'s alt attribute.
+		"""
+
+		loi_dom = None
+		if not self.loi_path:
+			with importlib.resources.files("se.data.templates").joinpath("loi.xhtml").open("r", encoding="utf-8") as file:
+				loi_dom = se.easy_xml.EasyXmlTree(file.read())
+
+			language = self.metadata_dom.xpath("/package/metadata/dc:language/text()")[0]
+			loi_dom.xpath("/html")[0].set_attr("xml:lang", language)
+		else:
+			loi_dom = self.get_dom(self.loi_path)
+
+		ols = loi_dom.xpath("/html/body/nav/ol")
+		if len(ols) != 1:
+			raise se.InvalidSeEbookException(f"LoI contains unexpected number of [html]<ol/>[/]: [path][link=file://{self.loi_path}]{self.loi_path}[/][/].")
+
+		etree.strip_elements(ols[0].lxml_element, "li")
+
+		for file_path in self.spine_file_paths:
+			dom = self.get_dom(file_path)
+
+			for figure in dom.xpath("/html/body//figure[@id and img]"):
+				figure_id = figure.get_attr("id")
+
+				entry = (figure.xpath("./img")[0].get_attr("alt") or "").strip()
+
+				figcaption = figure.xpath("./figcaption")
+				if figcaption:
+					figcaption_text = figcaption[0].inner_text()
+					# The alt text is probably more useful to the reader in this case.
+					if figcaption_text and not regex.search(r"^[Ff]igure\s+\d+$", figcaption_text):
+						has_block = False
+						for tag in se.css.CSS_BLOCK_ELEMENTS:
+							if figcaption[0].xpath(f"./{tag}"):
+								has_block = True
+								break
+
+						# Try to retain semantic phrasing structure.
+						if not has_block:
+							entry = deepcopy(figcaption[0])
+
+				a = se.easy_xml.EasyXmlElement("<a/>")
+				a.set_attr("href", f"{file_path.name}#{figure_id}")
+
+				if isinstance(entry, str):
+					a.set_text(entry or f"Unable to auto-generate LoI text for #{figure_id}.")
+				else:
+					a.append(entry)
+					entry.unwrap()
+
+				p = se.easy_xml.EasyXmlElement("<p/>")
+				p.append(a)
+
+				li = se.easy_xml.EasyXmlElement("<li/>")
+				li.append(p)
+				ols[0].append(li)
+
+		return se.formatting.format_xhtml(loi_dom.to_string())
+
 	def set_release_timestamp(self) -> None:
 		"""
 		If this ebook has not yet been released, set the first release timestamp in the metadata file.
@@ -1181,15 +1248,15 @@ class SeEpub:
 		halftitlepage, frontmatter = self.__add_to_spine([], frontmatter, "halftitlepage")
 
 		# Add any remaining frontmatter
-		spine = spine + natsorted([file_path.name for file_path in frontmatter])
+		spine += natsorted([file_path.name for file_path in frontmatter])
 
 		# The half title page is always the last front matter
-		spine = spine + halftitlepage
+		spine += halftitlepage
 
 		# Add bodymatter
 		spine, bodymatter = self.__add_to_spine(spine, bodymatter, "prologue")
 
-		spine = spine + natsorted([file_path.name for file_path in bodymatter])
+		spine += natsorted([file_path.name for file_path in bodymatter])
 
 		# Add backmatter
 		spine, backmatter = self.__add_to_spine(spine, backmatter, "afterword")
@@ -1203,11 +1270,11 @@ class SeEpub:
 		copyright_page, backmatter = self.__add_to_spine([], backmatter, "copyright-page")
 
 		# Add any remaining backmatter
-		spine = spine + natsorted([file_path.name for file_path in backmatter])
+		spine += natsorted([file_path.name for file_path in backmatter])
 
 		# Colophon and copyright page are always last
-		spine = spine + colophon
-		spine = spine + copyright_page
+		spine += colophon
+		spine += copyright_page
 
 		# Now build the spine output
 		spine_xml = "<spine>\n"
@@ -1328,7 +1395,7 @@ class SeEpub:
 						anchor = href[hash_position:]
 				references.append(anchor)  # keep these for later reverse check
 				# Now try to find anchor in endnotes
-				matches = list(filter(lambda x, old=anchor: x.anchor == old, self.endnotes)) # type: ignore [arg-type]
+				matches = list(filter(lambda x, old=anchor: x.anchor == old, self.endnotes)) # type: ignore [arg-type, var-annotated]
 				if not matches:
 					missing.append(anchor)
 				if len(matches) > 1:
@@ -1521,7 +1588,7 @@ class SeEpub:
 			link.lxml_element.text = str(current_note_number)
 			needs_rewrite = True
 		# Now try to find this in endnotes
-		matches = list(filter(lambda x, old=old_anchor: x.anchor == old, self.endnotes)) # type: ignore [arg-type]
+		matches = list(filter(lambda x, old=old_anchor: x.anchor == old, self.endnotes)) # type: ignore [arg-type, var-annotated]
 		if not matches:
 			raise se.InvalidInputException(f"Couldn’t find endnote with anchor [attr]{old_anchor}[/].")
 		if len(matches) > 1:
