@@ -109,7 +109,7 @@ class TocItem:
 					out_string += f"<a href=\"text/{self.file_link}\">{self.title}</a>\n"
 
 		# Replace <br/> with a single space
-		out_string = regex.sub(r"<br/>\s*", " ", out_string, flags=regex.DOTALL)
+		out_string = regex.sub(r"<br/>\s*", " ", out_string)
 
 		return out_string
 
@@ -200,7 +200,7 @@ def add_landmark(dom: EasyXmlTree, textf: str, landmarks: list) -> None:
 	if dom.xpath("//*[contains(@epub:type, 'frontmatter')]"):
 		return # We don't want frontmatter in the landmarks
 
-	if dom.xpath("//*[contains(@epub:type, 'backmatter')]") and not regex.findall(r"\b(loi|endnotes|bibliography|glossary|index)\b", epub_type):
+	if dom.xpath("//*[contains(@epub:type, 'backmatter')]") and not regex.search(r"\b(loi|endnotes|bibliography|glossary|index)\b", epub_type):
 		return # We only want certain backmatter in the landmarks
 
 	# We may wind up with a (front|body|back)matter semantic in epub_type, remove it here since we add it to the landmark later
